.. _index:

#####
tmuxp
#####

.. image:: _static/tmuxp-dev-screenshot.png
    :scale: 35%
    :width: 100%
    :align: right

.. include:: ../README.rst
    :start-line: 16
    :end-before: Project details

Explore:

.. toctree::
    :maxdepth: 2

    about
    quickstart
    examples
    cli
    internals
    developing
    api
    history
    roadmap
    about_tmux
    glossary
